/*
	Chapter 6
	Figure 6.12
	Validate model fit on first half to second half of data.
*/
version 11.0
set scheme sj
set more off
clear
use rott2

/*
	Scheme:
	0. Split the data 50:50 at random.
	1. Fit mfp model with scale(odds) to first half of patients.
	2. Predict prognostic index.
	3. Divide into 4 groups at 15/50/85 centiles of PI in first half.
	4. Predict individual survival in second half.
	5. Compute mean survival in same 4 groups in second half.
	6. Compute Kaplan-Meier curves in same 4 groups in second half.
	7. Compare predicted with KM graphically.
*/

// Create random 50:50 split of data
set seed 111
gen u = runiform()
sort u
gen byte half = cond(_n <= _N/2, 1, 2)

// Fit MFP model to first half of data
xi: stpm2 age enodes_1 pr_1 i.size grade chemo hormon if half == 1, ///
 scale(odds) df(2) all nolog

// Predict prognostic index (PI) for all patients
predict xb, xbnobaseline

// Compute centiles of PI on first half and
// create group indicators from saved cutpoints
centile xb if half == 1, centile(15 50 85)
gen byte g1 = (xb <= r(c_1))
gen byte g2 = (xb > r(c_1)) & (xb <= r(c_2))
gen byte g3 = (xb > r(c_2)) & (xb <= r(c_3))
gen byte g4 = (xb > r(c_3))

// Predict mean survival curve in each group, at observed times.
// Also predict corresponding Kaplan-Meier curves.
forvalues j = 1 / 4 {
	predict smean`j'  if (half == 2) & (g`j' == 1), meansurv
	sts gen km`j' = s if (half == 2) & (g`j' == 1)
}
line km1 km2 km3 km4 smean1 smean2 smean3 smean4 _t if half==2, ///
 sort c(J J J J l l l l) lpattern(l l l l - - - -) lcolor(gs4 ..) ///
 legend(order(1 5) label(1 "Kaplan-Meier in 2nd half of data") ///
 label(5 "Predicted from 1st half to 2nd half of data") ///
 ring(0) pos(7) col(1)) ///
 xtitle("Years from surgery") ytitle("Survival probability") ///
 ysca(r(0 1)) yla(0(0.25)1, angle(horizontal) format(%4.2f)) ///
 text(.78 10 "{&le} 15th centile", place(w)) ///
 text(.66 10 "15-50th centile", place(w)) ///
 text(.47 10 "50-85th centile", place(w)) ///
 text(.20 10 "> 85th centile", place(w))

// Discrimination statistics
// Compute R^2_D with the PI in each sample
str2d stpm2 xb if half == 1, scale(odds) df(2)
stcstat2
str2d stpm2 xb if half == 2, scale(odds) df(2)
stcstat2

set more on
