/*
	Chapter 7
	Time dependent stpm2 models.
	Includes figures 7.12, 7.13, 7.14, 7.15, 7.16, 7.17, 7.18
*/
version 11.0
set more off
clear
use ew_breast_ch7

stset survtime, failure(dead==1) exit(time 5) id(ident)

/* Proportional hazards model */
stpm2 dep5, scale(hazard) df(5)  nolog
range temptime 0.003 5 200
predict h_ph_dep0, hazard timevar(temptime) at(dep5 0) per(1000)
predict h_ph_dep1, hazard timevar(temptime) at(dep5 1) per(1000)

/* Model with time-dependent effects for dep5 */
stpm2 dep5, scale(hazard) df(5) tvc(dep5) dftvc(3) nolog

/* predict cumulative hazard */
predict ch_dep0, cumhaz timevar(temptime) at(dep5 0)
predict ch_dep1, cumhaz timevar(temptime) at(dep5 1)

// Figure 7.12
twoway 	(line ch_dep0 temptime, sort) ///
			(line ch_dep1 temptime, sort) ///
			, yscale(log) xscale(log) ///
			ytitle("Cumulative Hazard (log scale)") ///
			xtitle("Years from Diagnosis (log scale)") ///
			ylabel(0.01 0.05 0.1 0.2 0.4, format(%3.2f) angle(h)) yscale(log) ///
			xlabel(0.01 "0.01" 0.1 "0.1" 0.5 "0.5" 1 "1" 2 "2" 3 "3" 5 "5") ///
			legend(order(1 "Least Deprived" ///
				   2 "Most Deprived") ring(0) pos(5) cols(1)) 

// Figure 7.13
/* predict hazard rates */				  
predict h_tvc_dep0, hazard timevar(temptime) at(dep5 0) per(1000)
predict h_tvc_dep1, hazard timevar(temptime) at(dep5 1) per(1000)
twoway	(line h_ph_dep0 temptime if dep5 == 0 , sort lcolor(gs8) lpattern(solid) lwidth(thin)) ///
		(line h_ph_dep1 temptime if dep5 == 1 , sort lcolor(gs8) lpattern(dash) lwidth(thin)) ///
		(line h_tvc_dep0 temptime if dep5 == 0 , sort lcolor(black) lpattern(solid) lwidth(thick)) ///
		(line h_tvc_dep1 temptime if dep5 == 1 , sort lcolor(black) lpattern(dash) lwidth(thick)) ///
		, scheme(sj) ///
		legend(order(1 "Least deprived (PH)" 3 "Least deprived (TD)" ///
						2 "Most deprived (PH)" 4 "Most deprived (TD)") ring(0) pos(5) cols(1)) ///
		ylabel(,angle(h)) ytitle("Mortality rate (per 1000 person years)") yscale(log) ///
		xtitle("Time from Diagnosis (years)")

// Figure 7.14
/* predict hazard ratio */
predict hr, hrnum(dep5 1) hrdenom(dep5 0) timevar(temptime) ci
twoway	(rarea hr_lci hr_uci temptime if hr_uci<4, sort pstyle(ci)) ///
		(line hr temptime, sort lpattern(solid) lwidth(thick)) ///
		, scheme(sj) ///
		legend(off) ///
		ylabel(,angle(h)) ytitle(hazard ratio) ///
		xtitle("Time from Diagnosis (years)") ///
		yline(1, lpattern(dash) lwidth(thin)) yscale(log)

// Figure 7.15
/* predict hazard difference */
predict hdiff, hdiff1(dep5 1) hdiff2(dep5 0) timevar(temptime) ci per(1000)
twoway	(rarea hdiff_lci hdiff_uci temptime, sort pstyle(ci)) ///
		(line hdiff temptime, sort lpattern(solid) lwidth(thick)) ///
		, scheme(sj) ///
		legend(off) ///
		ylabel(,angle(h)) ytitle("Difference in mortality rate (per 1000 person years)") ///
		xtitle("Time from Diagnosis (years)") ///
		yline(0, lpattern(dash) lwidth(thin))

// Figure 7.16
/* predict survival */
predict s0, survival timevar(temptime) at(dep5 0)
predict s1, survival timevar(temptime) at(dep5 1)
twoway	(line s0 temptime, sort lwidth(thick)) ///
		(line s1 temptime, sort lwidth(thick)) ///
		, scheme(sj) ///
		legend(order(1 "Least Deprived" ///
					   2 "Most Deprived") ring(0) pos(1) cols(1)) ///
		ylabel(,angle(h) format(%3.1f)) ytitle("Proportion Alive") ///
		xtitle("Time from Diagnosis (years)") 

// Figure 7.17
/* predict survival difference */
predict sdiff, sdiff1(dep5 1) sdiff2(dep5 0) timevar(temptime) ci
twoway	(rarea sdiff_lci sdiff_uci temptime, sort pstyle(ci)) ///
		(line sdiff temptime, sort lpattern(solid) lwidth(thick)) ///
		, scheme(sj) ///
		legend(off) ///
		ylabel(-0.1(0.02)0.02,angle(h) format(%4.2f)) ytitle("Difference in Survival Curves") ///
		xtitle("Time from Diagnosis (years)") ///
		yline(0, lpattern(dash) lwidth(thin))

forvalues i = 1/5 {
	stpm2 dep5, scale(hazard) df(5) tvc(dep5) dftvc(`i')
	estimates store df`i'
	predict hr`i', hrnum(dep5 1) timevar(temptime) ci
}

/* Sensitivity analysis ... */
/* Note that the AIC values are incorrect in the book */
forvalues i = 1/5 {
	estimates restore df`i'
	local AIC = `:di %8.2f `e(AIC)''
	local BIC = `:di %8.2f `e(BIC)''
	local l`i' = "`i' df: AIC = `AIC', BIC=`BIC'"
}

// Figure 7.18
twoway 	(line hr1 temptime,) ///	
		(line hr2 temptime,) ///
		(line hr3 temptime,) ///
		(line hr4 temptime,) ///
		(line hr5 temptime,) ///
		, legend(order(1 "`l1'" 2 "`l2'" 3 "`l3'" 4 "`l4'" 5 "`l5'") ///
			pos(1) ring(0) cols(1)) ///
			yscale(log) ylabel(,angle(h)) ///
			xtitle("Years since diagnosis") ///
			ytitle("Hazard Ratio")
set more on
