/*
	Chapter 7
	Time-dependent stpm2 models with continuous age
	Includes figures 7.21, 7.22, table 7.1
*/
version 11.0
set more off	
clear

/* Load data, generate splines and fit PH model */
use ew_breast_alldep_ch7

stset survtime, failure(dead==1) exit(time 5) id(ident)

rcsgen agediag, df(4) gen(agercs) orthog
global ageknots `r(knots)'
matrix R=r(R)
stpm2 agercs1-agercs4, scale(hazard) df(5) nolog

/* Hazard ratio as a function of age with age 45 as the reference */
gen refage = 45 in 1
rcsgen refage in 1, knots($ageknots) gen(ragercs) rmatrix(R)
local c1 = ragercs1[1]
local c2 = ragercs2[1]
local c3 = ragercs3[1]
local c4 = ragercs4[1]
predict hr , hrnumerator(agercs1 . agercs2 . agercs3 . agercs4 .) ///
   hrdenominator(agercs1 `c1' agercs2 `c2' agercs3 `c3' agercs4 `c4') ci

// Figure 7.21
gen ageint = int(agediag)
bysort agediag: gen ageflag = _n == 1
twoway		(rarea	hr_lci hr_uci agediag if ageflag & agediag>=25 , sort pstyle(ci)) ///
			(line hr agediag if ageflag & agediag>=25, sort lwidth(thick) lpattern(solid)) ///
			, legend(off) ///
			xtitle("Age at Diagnosis") ///
			ytitle("Hazard Ratio") ///
			yscale(log) ///
			xscale(range(25 50)) ///
			xlabel(25(5)50) ///
			ylabel(1 1.2 1.5 2 2.5, angle(h))

/* Model with time-dependent effect of age */			
stpm2 agercs1-agercs4, scale(hazard) df(5) nolog tvc(agercs1-agercs4) dftvc(4)

/* Hazard ratio as a function of follow-up time for selected ages */
range temptime 0.003 5 200
foreach age in 25 35 40 50 {	
	gen agetmp = `age' in 1
	rcsgen agetmp in 1, knots($ageknots) gen(tmprcs) rmatrix(R)
	local b1 = tmprcs1[1]
	local b2 = tmprcs2[1]
	local b3 = tmprcs3[1]
	local b4 = tmprcs4[1]
	predict hr`age', hrnumerator(agercs1 `b1' agercs2 `b2' agercs3 `b3' agercs4 `b4') ///
 		hrdenominator(agercs1 `c1' agercs2 `c2'  agercs3 `c3' agercs4 `c4') ///
		timevar(temptime) ci
	predict s`age', survival at(agercs1 `b1' agercs2 `b2' agercs3 `b3' agercs4 `b4') ///
		timevar(temptime)
	drop agetmp tmprcs*
}

// Figure 7.22 !! does not match figure 7.22 in book pdf
foreach age in 25 35 40 50 {	
	twoway	(rarea hr`age'_lci hr`age'_uci temptime ///
				if hr`age'_lci>0.2 & hr`age'_uci<5, sort pstyle(ci)) ///
			(line hr`age' temptime, sort lwidth(thick) lpattern(solid)) ///
			(function y = 1, range(0 5) lpattern(dash)) ///
			, legend(off) scheme(sj) ///
			xtitle("Years from Diagnosis") ///
			ytitle("Hazard Ratio") ///
			yscale(log range(0.2 5)) ///
			ylabel(0.5  1  2 4, angle(h) format(%3.1f)) ///
			title("Age `age'") ///
			nodraw name(g`age',replace)
}
					
graph combine g25 g35 g40 g50, nocopies scheme(sj)

/* produce latex table of hazard ratios for selected ages at various
follow-up times */
range timeyear 1 5 5
foreach age in 25 35 40 50 {	
	gen tempage = `age' if _n <= 4
	rcsgen tempage, knots($ageknots) gen(tmprcs) rmatrix(R)
	local b1 = tmprcs1[1]
	local b2 = tmprcs2[1]
	local b3 = tmprcs3[1]
	local b4 = tmprcs4[1]
	predict hr`age'_year, hrnumerator(agercs1 `b1' agercs2 `b2' agercs3 `b3' agercs4 `b4') ///
						hrdenominator(agercs1 `c1' agercs2 `c2'  agercs3 `c3' agercs4 `c4') ///
						timevar(timeyear) ci
	drop tempage tmprcs*
}
local line
forvalues i = 1/5 {
	local line`i' "`i'" 
	foreach age in 25 35 40 50 {
		local hr = hr`age'_year[`i']
		local hr_lci = hr`age'_year_lci[`i']
		local hr_uci = hr`age'_year_uci[`i']
		local hradd: display " & " %4.2f `hr' " (" %4.2f `hr_lci' "," %4.2f `hr_uci' ")"
		local line`i' `line`i'' `hradd'
	}
}

// Table 7.1
capture file close hr
file open hr using  "ch7_s_hazard_ratio_table.tex", replace write
file write hr "\begin{table}[tbp]" ///
		_newline "\caption{Hazard Ratios at years 1-5 for selected ages with age 45 as the reference}" ///
		_newline "\label{ch7_s:hazard_ratio_table}" ///
		_newline "\begin{tabular}{lcccc}" ///
		_newline "\hline" ///
		_newline "Year & Age 25 & Age 35 & Age 40 & Age 50 \\" ///
		_newline "\hline" ///
		_newline "`line1' \\" ///
		_newline "`line2' \\" ///
		_newline "`line3' \\" ///
		_newline "`line4' \\" ///
		_newline "`line5' \\" ///
		_newline "\hline" ///
		_newline "\end{tabular}" /// 
		_newline "\end{table}"
file close hr
set more on
